@@ -36,7 +36,7 @@ void Audio::createWav(QString filename)
         QString program = "flite"; //espeak
         QStringList arguments;
 
-        arguments << "-f" << filename << "-o" << audio; //arguments << "-f" << filename << "-s" << "110" << "-v " << "en/en-rp" << -w << audio;
+        arguments << "-f" << QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + filename << "-o" << audio; //arguments << "-f" << filename << "-s" << "110" << "-v " << "en/en-rp" << -w << audio;
         qDebug()<<arguments;
         QProcess *myProcess = new QProcess();
 
